<?php 
// Publizjr Basic Generator Template
// Assembles article parts into html web pages.
// http://www.omegajunior.net/code/publizjr/
// (c) A.E.Veltstra, 1993 - 2012

//enable output gzipping:
ob_start( 'ob_gzhandler' );

//remove comment chars to enable error reporting:
//error_reporting( E_ALL );
//ini_set( 'display_errors', true );

//this is our BBCode Parser. We assume it exists in the same folder as this template. Otherwise, adjust the file location. Remember this is a file path - not a URL.
require( 'bb2html.php' );

//helper functions
function ParseBBCode ( $strInput ) {
  return bb2html( htmlspecialchars( strip_tags( $strInput ) ) );
}
function ParseNoCode ( $strInput ) {
  return nl2br( htmlspecialchars( strip_tags( $strInput ) ) );
}
function ReadPart ( $strPartname, $bArray = false, $strDefault = '' ) {
 if( $bArray ){
  return ( file_exists( $strPartname ) ? file( $strPartname ) : Array() );
 } else {
  return trim( file_exists( $strPartname ) ? file_get_contents( $strPartname ) : $strDefault );
 }
}

//tell the browser what we're generating
header( 'content-type: text/html; charset=UTF-8' );

//tell the world that you're using Publizjr
header( 'x-generated-by: Publizjr. http://www.omegajunior.net/code/publizjr/' );

//allow proxies and browsers to cache our output, but check for updates
header( 'cache-control: public, cache, must-revalidate' );
header( 'pragma: cache' );

//We listen to the 'id' query parameter, 
//and take its value to identify the desired page.
//This page id is expecte to equal a folder name.
$strFileID = htmlspecialchars( $_GET[ 'id' ] );

//if no page id was provided, show the index
if ( strlen( $strFileID ) == 0 ) {
 $strFileID = 'index';
	$strBodyClass = ' class="index"';
}else{
	$strBodyClass = ' class="' . preg_replace('/[^-_a-zA-Z0-9]/', '', $strFileID) . '"';
}

//only required text: the body
$fileName = "./$strFileID/body";

//it should exist and be a file
if( file_exists( $fileName ) == false || is_file( $fileName ) == false ){ $fileName = ''; }
$bExists = ( strlen( $strFileID ) > 0 && strlen( $fileName ) > 0 );

//if not, generate a 404 notification
if( $bExists === false ){
  $lastModDate = date( 'Y-m-d H:i', getlastmod(  ) );
  $strFileTitle = ReadPart( "translations/404title", false, '404 Not Found' ) ;
  header( 'status: 404', true ); 
  header( 'HTTP/1.0 404 Not Found', true );
}else{
  $lastModDate = date( 'Y-m-d H:i', filectime( "./$strFileID/" ) );
  $strFileTitle = ParseNoCode( ReadPart( "./$strFileID/title" ) );
}

//let the browser know when the body was changed last, to help them refresh their cache
header( 'last-modified: ' . $lastModDate, true ); 

?>
<!DOCTYPE html>
<html lang="en">

<head>
  <meta name="charset" content="UTF-8">
  <?php /* The second part of the title, with the company name, is editable here, because we expect the generated web pages to need different titles based on the site hierarchy */ ?>
  <title><?php print( $strFileTitle ); ?> - My ( Company ) Name</title>
<?php 
$fileAuthor = ParseNoCode( ReadPart( "./$strFileID/author", false, '' ) );
if ( strlen($fileAuthor) ) {
  print( "<meta name=\"author\" content=\"$fileAuthor\">" );
}
$strFilePath = "./$strFileID/description";
print( '<meta name="description" content="' . strip_tags( ParseNoCode( ReadPart( $strFilePath, false, 'Add a default description' ) ) ) . '">' );
?>
  <meta name="generator" content="Publizjr">
  <link rel="canonical" href="http://sub.domain.tld/?id=<?php print($strFileID); ?>">
  <link rel="icon" href="/favicon.ico">
  <link rel="shortcut icon" href="/favicon.ico">
  <link rel="home" title="Home" href="/">
  <link rel="contents" title="Sitemap" href="?id=sitemap">
  <link rel="stylesheet" title="Publizjr Plain Style" media="all" id="publizjr.css" href="publizjr.css">
</head>

<body <?php print( $strBodyClass ); ?>>

<aside class=pagePath>
  <?php /* The first part of this breadcrumb, with the domain name or home, is editable here, because we expect the generated web pages to need different breadcrumbs based on the site hierarchy */ ?>
<a href="/" rel="home">Home</a> &gt; <?php print( $strFileTitle ); ?>
<hr></aside>

<article>
 <h1><?php print( $strFileTitle ); ?></h1>

<?php
print( ReadPart( "translations/warningDeprecatedBrowser", false, '' ) );

 if( $bExists ){ 
   $fileIntro = ReadPart( "./$strFileID/intro" );
   if( strlen( $fileIntro ) ){
     print( '<p class="intro">' . ParseNoCode( $fileIntro ) . "</p>\r" ); 
   }
   $fileBody = ReadPart( "./$strFileID/body" );
   if( strlen( $fileBody ) ){
     print( '<div class="body">' . ParseBBCode( $fileBody ) . "</div>\r" );
   }    
   $fileLinks = ReadPart( "./$strFileID/links", true );
   if( is_array( $fileLinks ) && count( $fileLinks ) > 0 ){
     print( '<h2>' . ReadPart( 'translations/morelinks', false, 'Related:' ) . "</h2>\r" . '<ul class="related">' );
     foreach( $fileLinks as $link ){
       $arrLink = explode( '" <', substr( trim( $link ), 1, -1 ), 2 );
       if( is_array( $arrLink ) ){
         if( $arrLink[1] ){
          print( '<li><a href="' . $arrLink[ 1 ] . '">' . $arrLink[ 0 ] . "</a></li>\r" );
         }else{
          print( '<li>' . $arrLink[ 0 ] . "</li>\r" );
         }
       }
     }
     print( "</ul>\r" ); 
   }
 } else { 
   print( '<p>' . ReadPart( 'translations/404friendlyMessage', false, 'Does that address exist?' ) . "</p>\r" );
 } ?>
</article>
<footer>
 <p><a href="../" title="Home" rel="home">&copy; &Omega;Jr. 1993 - 2012</a>. <?php print( ReadPart( 'translations/lastModified', false, 'Last modification:' ).' '.$lastModDate ); ?></p>
 <address><div align="right">Powered by <a href="http://www.omegajunior.net/code/publizjr/">Publizjr.</div></address>
</footer>
</body>
</html>