<?php 
// Multilanguage Publizjr Generator Template.
// http://www.omegajunior.net/code/publizjr/
// Assembles article parts into html web pages.
// 
// ( c ) A.E.Veltstra, 1993 - 2012

//enable output gzipping:
ob_start( 'ob_gzhandler' );

//remove comment chars to enable error reporting:
//error_reporting( E_ALL );
//ini_set( 'display_errors', true );

//this is our BBCode Parser. We assume it exists in the same folder as this template. Otherwise, adjust the file location. Remember this is a file path - not a URL.
require( 'bb2html.php' );

//this is our language detector. The same assumption applies as above.
require( 'detectlang.php' );

//helper functions
function ParseBBCode ( $strInput ) {
  return bb2html( htmlspecialchars( strip_tags( $strInput ) ) );
}
function ParseNoCode ( $strInput ) {
  return nl2br( htmlspecialchars( strip_tags( $strInput ) ) );
}
function ReadPart ( $strPartname, $bArray = false, $strDefault = '' ) {
 if( $bArray ){
  return ( file_exists( $strPartname ) ? file( $strPartname ) : Array() );
 } else {
  return trim( file_exists( $strPartname ) ? file_get_contents( $strPartname ) : $strDefault );
 }
}

//tell the browser what we're generating
header( 'content-type: text/html; charset=UTF-8' );

//tell the world that you're using Publizjr
header( 'x-generated-by: Publizjr. http://www.omegajunior.net/code/publizjr/' );

//allow proxies and browsers to cache our output, but check for updates
header( 'cache-control: public, cache, must-revalidate' );
header( 'pragma: cache' );

//We listen to the 'id' query parameter, 
//and take its value to identify the desired page.
//This page id is expected to equal a folder name.
$strFileID = '';
if ( !empty( $_GET[ 'id' ] ) ) {
	$strFileID = htmlspecialchars( $_GET[ 'id' ] );
}

//if no id parameter exists, show the index
if ( strlen( $strFileID ) == 0 ) {
 $strFileID = 'index';
	$strBodyClass = ' class="index"';
}else{
	$strBodyClass = ' class="' . preg_replace('/[^-_a-zA-Z0-9]/', '', $strFileID) . '"';
}

//we ask the visitor's browser which language they prefer
$strRequestLang = zjrAcceptLanguage();

//adjust the fileID to include the language preference
$strOriginalFileID = $strFileID;
if ( strlen( $strRequestLang ) > 0 ) {
 if ( file_exists( $strFileID . '/' . $strRequestLang ) !== false && is_dir( $strFileID . '/' . $strRequestLang ) !== false ) {
  $strFileID = $strFileID . '/' . $strRequestLang;
 }
}

//Determine existence of the only required text
$strFilePath = "./$strFileID/body";
if ( file_exists( $strFilePath ) == false || is_file( $strFilePath ) == false ) {
  $strFilePath = '';
}
$bExists = ( strlen( $strFileID ) > 0 && strlen( $strFilePath ) > 0 );

//Maybe we need to show a 404 message?
if ( $bExists === false ) {
	$lastModDate = date( 'Y-m-d H:i',getlastmod() );
 $strFilePath = "translations/$strRequestLang/404title";
 $strTitle = ParseNoCode( ReadPart( $strFilePath, false, '404 Not Found' ) );
	header( 'status: 404', true ); 
	header( 'HTTP/1.0 404 Not Found', true );
	$strFileID = "not-found-404";
} else {
 $lastModDate = date( 'Y-m-d H:i',filectime( "./$strFileID/" ) );
 $strTitle = ParseNoCode( ReadPart( "./$strFileID/title", false, 'No Title' ) );
}

//Tell the proxies and browsers whether to renew their caches
header( 'last-modified: ' . $lastModDate, true ); 

?>
<!DOCTYPE html>
<html lang="<?php print( $strRequestLang ); ?>">
<head>
  <meta name="charset" content="UTF-8">
  <title><?php print( $strTitle ); /* append any title parts the site hierarchy requires */ ?> - MyDomain.com</title>
<?php 
$fileAuthor = ParseNoCode( ReadPart( "./$strFileID/author", false, '' ) );
if ( strlen($fileAuthor) ) {
  print( "<meta name=\"author\" content=\"$fileAuthor\">" );
}
$strFilePath = "./$strFileID/description";
print( '<meta name="description" content="' . strip_tags( ParseNoCode( ReadPart( $strFilePath, false, 'Add a default description' ) ) ) . '">' );
?>
  <link rel="canonical" href="http://sub.domain.tld/?id=<?php print($strOriginalFileID); ?>">
  <link rel="icon" href="favicon.ico">
  <link rel="shortcut icon" href="favicon.ico">
  <link rel="home" title="Home" href="/">
  <link rel="contents" title="Sitemap" href="?id=sitemap">
  <link rel="stylesheet" title="Publizjr Plain Style" media="all" id="publizjr.css" href="publizjr.css">
  
</head>

<body <?php print( $strBodyClass ); ?>>

<aside class=pagePath>
  <?php /* The first part of this breadcrumb, with the domain name or home, is editable here, because we expect the generated web pages to need different breadcrumbs based on the site hierarchy */ ?>
<a href="/" rel="home">Home</a> &gt; <?php print( $strTitle ); ?>
<hr></aside>
<article>
 <h1><?php print( $strTitle ); ?></h1>

<?php 
$strFilePath = "translations/$strRequestLang/warningDeprecatedBrowser";
print( ReadPart( $strFilePath, false, '' ) );

if ( $bExists ) { 
   
   $strText = ReadPart( "./$strFileID/intro" );
   if ( strlen( $strText ) ) {
     print( '<p class="intro">' . ParseNoCode( $strText ) . "</p>\r" ); 
   }
   $strText = ReadPart( "./$strFileID/body" );
   if ( strlen( $strText )>0 ) {
     print( '<div class="body">' . ParseBBCode( $strText ) . "</div>\r" );
   }    
   $arrLinks = ReadPart( "./$strFileID/links", true );
   if ( is_array( $arrLinks ) && count( $arrLinks ) > 0 ) {
     $strFilePath="translations/$strRequestLang/morelinks";
     print( '<h2 class="related">' . ReadPart( $strFilePath, false, 'Explore' ) . ":</h2>\r" );
     print( '<ul class="related">' );
     foreach( $arrLinks as $strLink ) {
       $arrLink = explode( '" <', substr( trim( $strLink ), 1, -1 ), 2 );
       if ( is_array( $arrLink ) ) {
         print( '<li><a href="' . $arrLink[ 1 ] . '">' . $arrLink[ 0 ] . "</a></li>\r" );
       }
     }
     print( "</ul>\r" ); 
   }
 } else { 
  $strFilePath = "translations/$strRequestLang/404friendlyMessage";
  print( '<p>' . ReadPart( $strFilePath, false, 'Does that address exist?' ) . '</p>' );
 } ?>
</article>
<footer>
 <p><a href="../" title="Home" rel="home">&copy; &Omega;Jr. 1993 - 2012</a>. <?php print( ReadPart( 'translations/lastModified', false, 'Last modification:' ).' '.$lastModDate ); ?></p>
 <address><div align="right">Powered by <a href="http://www.omegajunior.net/code/publizjr/">Publizjr.</div></address>
</footer>
</body>
</html>